@@ -1,19 +1,25 @@
 #A* -------------------------------------------------------------------
 #B* This file contains source code for the PyMOL computer program
-#C* Copyright (c) Schrodinger, LLC. 
+#C* Copyright (c) Schrodinger, LLC.
 #D* -------------------------------------------------------------------
 #E* It is unlawful to modify or remove this copyright notice.
 #F* -------------------------------------------------------------------
-#G* Please see the accompanying LICENSE file for further information. 
+#G* Please see the accompanying LICENSE file for further information.
 #H* -------------------------------------------------------------------
 #I* Additional authors of this source file include:
-#-* 
-#-* 
+#-*
+#-*
 #-*
 #Z* -------------------------------------------------------------------
 
 from __future__ import print_function
 
+import sys
+if sys.version_info[0] == 2:
+    _next_method_name = 'next'
+else:
+    _next_method_name = '__next__'
+
 cmd = __import__("sys").modules["pymol.cmd"]
 import pymol
 from pymol import movie
@@ -110,7 +116,7 @@ ARGUMENTS
         _self.get_area(tmpSel, load_b=1)
         _self.spectrum("b", palette, tmpSel)
         _self.iterate(tmpSel, "l_a(color)", space={'l_a': l.append})
-        _self.alter(orgSel, "color=l_n()", space={'l_n': iter(l).__next__})
+        _self.alter(orgSel, "color=l_n()", space={'l_n': getattr(iter(l), _next_method_name)})
 
         _self.recolor(orgSel)
     finally:
@@ -219,8 +225,7 @@ SEE ALSO
     _self.select(tmpSel, sele, 0)
 
     if state < 1:
-        from pymol import querying
-        state = querying.get_selection_state(tmpSel)
+        state = _self.get_selection_state(tmpSel)
 
     tmpObj = _self.get_unused_name("_tmp")
     _self.create(tmpObj, "(byobj ?%s) & ! solvent" % (tmpSel), state, zoom=0)
@@ -266,7 +271,7 @@ def mass_align(target,enabled_only=0,max_gap=50,_self=cmd):
                 cmd.align('polymer and name CA and (%s)'%name,
                 'polymer and name CA and (%s)'%target,max_gap=max_gap,quiet=0,
                           object=aln_object)
-    
+
 def sum_formal_charges(selection="(all)",quiet=1,_self=cmd):
     _util_sum_fc = [0]
     _self.iterate(selection, "_util_sum_fc[0] += formal_charge", space=locals())
@@ -332,14 +337,14 @@ NOTES
     if not quiet:
         print(" util.compute_mass: mass = %0.4f u"%result)
     return result
-    
+
 def protein_assign_charges_and_radii(obj_name,_self=cmd):
     cmd=_self
 
     from chempy.champ import assign
 
     # apply a few kludges
-    
+
     # convent Seleno-methionine to methionine
 
     cmd.alter(obj_name+"///MSE/SE","elem='S';name='SD'",quiet=1)
@@ -352,37 +357,37 @@ def protein_assign_charges_and_radii(obj_name,_self=cmd):
     cmd.alter(obj_name,"alt=''")
     cmd.sort(obj_name)
     cmd.fix_chemistry(obj_name,obj_name,1)
-    
+
     # make sure all atoms are included...
     cmd.alter(obj_name,"q=1.0",quiet=1)
-    
+
     print(" Util: Fixing termini and assigning formal charges...")
-    
+
     assign.missing_c_termini(obj_name,quiet=1,_self=_self)
 
     while not assign.formal_charges(obj_name,quiet=1,_self=_self):
         print(" WARNING: unrecognized or incomplete residues are being deleted:")
         cmd.iterate("(byres ("+obj_name+" and flag 23)) and flag 31",
-                        'print "  "+model+"/"+segi+"/"+chain+"/"+resn+"`"+resi+"/"',quiet=1)
+                        'print("  "+model+"/"+segi+"/"+chain+"/"+resn+"`"+resi+"/")',quiet=1)
         cmd.remove("byres ("+obj_name+" and flag 23)") # get rid of residues that weren't assigned
         assign.missing_c_termini(obj_name,quiet=1,_self=_self)
-        
+
     print(" Util: Assigning Amber 99 charges and radii...")
-    
+
     cmd.h_add(obj_name)
     if not assign.amber99(obj_name,quiet=1,_self=_self):
         print(" WARNING: some unassigned atoms are being deleted:")
         cmd.iterate("byres ("+obj_name+" and flag 23)",
-                        'print "  "+model+"/"+segi+"/"+chain+"/"+resn+"`"+resi+"/"+name+"? ["+elem+"]"',quiet=1)
+                        'print("  "+model+"/"+segi+"/"+chain+"/"+resn+"`"+resi+"/"+name+"? ["+elem+"]")',quiet=1)
         cmd.remove(obj_name+" and flag 23") # get rid of any atoms that weren't assigned
-        
+
     # show the user what the net charges are...
-        
+
     formal = sum_formal_charges(obj_name,quiet=0,_self=_self)
     partial = sum_partial_charges(obj_name,quiet=0,_self=_self)
     if round(formal)!=round(partial):
         print(" WARNING: formal and partial charge sums don't match -- there is a problem!")
-    
+
 def protein_vacuum_esp(selection, mode=2, border=10.0, quiet = 1, _self=cmd):
     cmd=_self
 
@@ -403,7 +408,7 @@ def protein_vacuum_esp(selection, mode=2, border=10.0, quiet = 1, _self=cmd):
          # try to just get protein...
 
     protein_assign_charges_and_radii(obj_name,_self=_self)
-        
+
     ext = cmd.get_extent(obj_name)
     max_length = max(abs(ext[0][0] - ext[1][0]),abs(ext[0][1] - ext[1][1]),abs(ext[0][2]-ext[1][2])) + 2*border
 
@@ -417,19 +422,19 @@ def protein_vacuum_esp(selection, mode=2, border=10.0, quiet = 1, _self=cmd):
     elif mode==1: # neutral, no cutoff
         cmd.map_new(map_name,"coulomb_neutral",sep,obj_name,border)
     else: # local, with cutoff
-        cmd.map_new(map_name,"coulomb_local",sep,obj_name,border)      
-        
+        cmd.map_new(map_name,"coulomb_local",sep,obj_name,border)
+
     cmd.ramp_new(pot_name, map_name, selection=obj_name,zero=1)
     cmd.hide("everything",obj_name)
     cmd.show("surface",obj_name)
     cmd.set("surface_color",pot_name,obj_name)
     cmd.set("surface_ramp_above_mode",1,obj_name)
-    
+
 def color_carbon(color,selection="(all)",_self=cmd):
     cmd=_self
     selection = str(selection)
     cmd.color(color,"(%s) and elem C"%selection)
-    
+
 def cbss(selection="(all)",helix_color="red",sheet_color="yellow",loop_color="green",quiet=1,_self=cmd):
     cmd=_self
     sel = str(selection)
@@ -446,67 +451,67 @@ def cbag(selection="(all)",quiet=1,_self=cmd):
     s = str(selection)
     cmd.color("atomic","(("+s+") and not elem C)",quiet=quiet)
     cmd.color("carbon","(elem C and ("+s+"))",quiet=quiet)
-    
+
 def cbac(selection="(all)",quiet=1,_self=cmd):
     '''Wrapper around "color atomic"'''
     cmd=_self
     s = str(selection)
     cmd.color("atomic","(("+s+") and not elem C)",quiet=quiet)
     cmd.color("cyan","(elem C and ("+s+"))",quiet=quiet)
-    
+
 def cbam(selection="(all)",quiet=1,_self=cmd):
     '''Wrapper around "color atomic"'''
     cmd=_self
-    s = str(selection)   
+    s = str(selection)
     cmd.color("atomic","(("+s+") and not elem C)",quiet=quiet)
     cmd.color("lightmagenta","(elem C and ("+s+"))",quiet=quiet)
 
 def cbay(selection="(all)",quiet=1,_self=cmd):
     '''Wrapper around "color atomic"'''
     cmd=_self
-    s = str(selection)   
+    s = str(selection)
     cmd.color("atomic","(("+s+") and not elem C)",quiet=quiet)
     cmd.color("yellow","(elem C and ("+s+"))",quiet=quiet)
 
 def cbas(selection="(all)",quiet=1,_self=cmd):
     '''Wrapper around "color atomic"'''
     cmd=_self
-    s = str(selection)   
+    s = str(selection)
     cmd.color("atomic","(("+s+") and not elem C)",quiet=quiet)
     cmd.color("salmon","(elem C and ("+s+"))",quiet=quiet)
 
 def cbaw(selection="(all)",quiet=1,_self=cmd):
     '''Wrapper around "color atomic"'''
     cmd=_self
-    s = str(selection)   
+    s = str(selection)
     cmd.color("atomic","(("+s+") and not elem C)",quiet=quiet)
     cmd.color("hydrogen","(elem C and ("+s+"))",quiet=quiet)
 
 def cbab(selection="(all)",quiet=1,_self=cmd):
     '''Wrapper around "color atomic"'''
     cmd=_self
-    s = str(selection)   
+    s = str(selection)
     cmd.color("atomic","(("+s+") and not elem C)",quiet=quiet)
     cmd.color("slate","(elem C and ("+s+"))",quiet=quiet)
 
 def cbao(selection="(all)",quiet=1,_self=cmd):
     '''Wrapper around "color atomic"'''
     cmd=_self
-    s = str(selection)   
+    s = str(selection)
     cmd.color("atomic","(("+s+") and not elem C)",quiet=quiet)
     cmd.color("brightorange","(elem C and ("+s+"))",quiet=quiet)
 
 def cbap(selection="(all)",quiet=1,_self=cmd):
     '''Wrapper around "color atomic"'''
     cmd=_self
-    s = str(selection)   
+    s = str(selection)
     cmd.color("atomic","(("+s+") and not elem C)",quiet=quiet)
     cmd.color("purple","(elem C and ("+s+"))",quiet=quiet)
 
 def cbak(selection="(all)",quiet=1,_self=cmd):
     '''Wrapper around "color atomic"'''
     cmd=_self
-    s = str(selection)   
+    s = str(selection)
     cmd.color("atomic","(("+s+") and not elem C)",quiet=quiet)
     cmd.color("pink","(elem C and ("+s+"))",quiet=quiet)
 
@@ -558,7 +563,7 @@ def modernize_rendering(mode,_self=cmd):
     and quality.
     """
     cmd = _verbose_cmd_proxy(_self)
-    
+
     cmd.set("max_ups",0)
 
     enable_all_shaders(cmd)
@@ -574,7 +579,7 @@ def performance(mode,_self=cmd):
     mode = int(mode)
     if mode==0: # maximum quality
         cmd.set('line_smooth',1)
-        cmd.set('depth_cue',1)         
+        cmd.set('depth_cue',1)
         cmd.set('specular',1)
         cmd.set('surface_quality',1)
         cmd.set('cartoon_sampling',14)
@@ -610,8 +615,8 @@ def performance(mode,_self=cmd):
             cmd.set('sphere_quality',2)
             cmd.set('stick_ball',1)
     elif mode==33:
-        cmd.set('line_smooth',1)         
-        cmd.set('depth_cue',1)         
+        cmd.set('line_smooth',1)
+        cmd.set('depth_cue',1)
         cmd.set('specular',1)
         cmd.set('surface_quality',0)
         cmd.set('cartoon_sampling',7)
@@ -649,7 +654,7 @@ def performance(mode,_self=cmd):
 
     elif mode==66: # good perfomance
         cmd.set('line_smooth',0)
-        cmd.set('depth_cue',0)         
+        cmd.set('depth_cue',0)
         cmd.set('specular',1)
         cmd.set('surface_quality',0)
         cmd.set('cartoon_sampling',6)
@@ -718,7 +723,7 @@ def performance(mode,_self=cmd):
 
     cmd.do("rebuild")
 
-    
+
 def label_chains(sele="all",_self=cmd):
     pymol=_self._pymol
     cmd=_self
@@ -738,9 +743,9 @@ def label_chains(sele="all",_self=cmd):
     list = [_f for _f in list if _f]
     for a in list:
         if(a[1]==''):
-            cmd.label("%s`%d"%(a[0],a[2]),'''"chain ''"''',quiet=1)         
+            cmd.label("%s`%d"%(a[0],a[2]),'''"chain ''"''',quiet=1)
         elif(a[1]==' '):
-            cmd.label("%s`%d"%(a[0],a[2]),'''"chain ' '"''',quiet=1)         
+            cmd.label("%s`%d"%(a[0],a[2]),'''"chain ' '"''',quiet=1)
         else:
             cmd.label("%s`%d"%(a[0],a[2]),"'chain '+chain",quiet=1)
 
@@ -763,22 +768,12 @@ def label_segments(sele="all",_self=cmd):
     list = [_f for _f in list if _f]
     for a in list:
         if(a[1]==''):
-            cmd.label("%s`%d"%(a[0],a[2]),'''"segi ''"''',quiet=1)         
+            cmd.label("%s`%d"%(a[0],a[2]),'''"segi ''"''',quiet=1)
         elif(a[1]==' '):
-            cmd.label("%s`%d"%(a[0],a[2]),'''"segi ' '"''',quiet=1)         
+            cmd.label("%s`%d"%(a[0],a[2]),'''"segi ' '"''',quiet=1)
         else:
             cmd.label("%s`%d"%(a[0],a[2]),"'segi '+segi",quiet=1)
 
-    
-# legacy
-from pymol.selecting import deselect as hide_sele # noqa
-
-# FUBAR
-#def hbond(a,b,cutoff=3.3,name='hbond'):
-#   cmd.dist(name,"((%s) and ((%s) around %4.2f) and elem N,O)"%(a,b,cutoff),
-#            "((%s) and ((%s) around %4.2f) and elem N,O)"%(b,a,cutoff),
-#            cutoff)
-
 def cbc(selection='(all)',first_color=7,quiet=1,legacy=0,_self=cmd):
     '''
     Color all chains a different color
@@ -794,9 +789,9 @@ def cbc(selection='(all)',first_color=7,quiet=1,legacy=0,_self=cmd):
         if not quiet:
             print(" util.cbc: color %s, (chain %s)" % (color, a))
         _self.color(color, "(chain %s and (%s))" % (a, selection), quiet=quiet)
-        
+
 def color_objs(selection='(all)',quiet=1,_self=cmd):
-    cmd=_self 
+    cmd=_self
     '''
     Color all chains a different color
     '''
@@ -813,10 +808,8 @@ def color_deep(color, name='all', quiet=1, _self=cmd):
     Unset all object and atom level (not global) color settings and
     apply given color.
     '''
-    from pymol.menu import rep_setting_lists
-    _self.unset_deep([s for L in rep_setting_lists for (r, s) in L if s],
-            name, updates=0, quiet=quiet)
-    _self.color(color, name, quiet=quiet, _self=_self)
+    print(' util.color_deep: Deprecated, use cmd.color_deep() instead')
+    _self.color_deep(color, name, quiet)
 
 def chainbow(selection='(all)', palette="rainbow", quiet=1, _self=cmd):
     '''
@@ -827,11 +820,8 @@ def chainbow(selection='(all)', palette="rainbow", quiet=1, _self=cmd):
             _self.spectrum('count', palette,
                     "(chain '%s' & model %s & (%s))" % (a, model, selection),
                     byres=1, quiet=quiet)
-            
-color_chains = cbc
 
-# legacy
-sum_charge = sum_partial_charges
+color_chains = cbc
 
 def ray_shadows(mode,_self=cmd):
     cmd = _verbose_cmd_proxy(_self)
@@ -840,7 +830,7 @@ def ray_shadows(mode,_self=cmd):
         cmd.set('ray_shadow',0)
     else:
         cmd.set('ray_shadow',1)
-    if mode=='light': 
+    if mode=='light':
         cmd.set('light_count',2)
         cmd.set("light","[-0.4,-0.4,-1.0]")
         cmd.set('ambient',0.14)
@@ -863,7 +853,7 @@ def ray_shadows(mode,_self=cmd):
         cmd.set('reflect',0.45)
         cmd.set('shininess',25)
         cmd.set('power',1.25)
-        cmd.set('spec_count',-1)                
+        cmd.set('spec_count',-1)
         cmd.set('specular_intensity',0.2)
         cmd.set('spec_direct',0)
         cmd.set('ray_shadow_decay_factor',0)
@@ -885,7 +875,7 @@ def ray_shadows(mode,_self=cmd):
         cmd.set('spec_count',1)
         cmd.set('shininess',55)
         cmd.set('power',1.0)
-        cmd.set('spec_direct',0)        
+        cmd.set('spec_direct',0)
         cmd.set('ray_shadow_decay_factor',0.1)
         cmd.set('ray_shadow_decay_range',1.8)
     elif mode=='occlusion':
@@ -902,7 +892,7 @@ def ray_shadows(mode,_self=cmd):
         cmd.set('direct',0.10)
         cmd.set('reflect',0.80)
         cmd.set('shininess',10)
-        cmd.set('spec_count',-1)        
+        cmd.set('spec_count',-1)
         cmd.set('power',1.0)
         cmd.set('specular_intensity',0)
         cmd.set('spec_direct',0.25)
@@ -934,14 +924,14 @@ def ray_shadows(mode,_self=cmd):
         cmd.set('spec_direct',0)
         cmd.set('ray_shadow_decay_factor',0)
     elif mode=='heavy':
-        cmd.set('light_count',2)        
+        cmd.set('light_count',2)
         cmd.set("light","[-0.4,-0.4,-1.0]")
         cmd.set('ambient',0.05)
         cmd.set('direct',0.20)
         cmd.set('reflect',0.85)
         cmd.set('spec_count',-1)
-        cmd.set('shininess',90) 
-        cmd.set('power',1.0) 
+        cmd.set('shininess',90)
+        cmd.set('power',1.0)
         cmd.set('specular_intensity',0.5)
         cmd.set('spec_direct',0)
         cmd.set('ray_shadow_decay_factor',0)
@@ -957,7 +947,7 @@ def ray_shadows(mode,_self=cmd):
         cmd.set('specular_intensity',0.5)
         cmd.set('spec_direct',0)
         cmd.set('ray_shadow_decay_factor',0)
-        
+
 def ff_copy(src,dst,_self=cmd):
     pymol=_self._pymol
     cmd=_self # NOT THREAD SAFE
@@ -969,12 +959,12 @@ def ff_copy(src,dst,_self=cmd):
     cmd.iterate("(%s)"%src,"_rcopy.tt[name]=text_type")
     cmd.alter("(%s)"%dst,"text_type=_rcopy.tt[name]")
     del pymol._rcopy
-    
+
 def b2vdw(selection='all', _self=cmd):
     # use B values to create RMS VDW spheres
     # rms = sqrt(b/(8*(PI^2)))
     _self.alter(selection, "vdw=(b/78.9568352087)**0.5")
-    
+
 def phipsi(selection="(pk1)",_self=cmd):
     cmd=_self # NOT THREAD SAFE
     n_sele =   "((byres (%s)) & name N)"%selection
@@ -1011,540 +1001,35 @@ def rainbow(selection="(name CA and alt ''+A)",reverse=0,_self=cmd):
 
     Use instead: spectrum
     '''
-    cmd=_self # NOT THREAD SAFE
-
-    cmd.feedback("push")
-    cmd.feedback("disable","executive","actions")
-
-    # your basic rainbow...
-    
+    print(' util.rainbow: Deprecated, use cmd.spectrum() instead')
     list = [
-        (0,0,255),      
+        (0,0,255),
         (0,0,255),
         (0,128,255),
         (0,255,255),
-        (0,255,128),           
+        (0,255,128),
         (0,255,0),
         (128,255,0),
         (255,255,0),
         (255,128,0),
         (255,0,0),
-        (255,0,0)      
+        (255,0,0)
         ]
     if reverse:
         list.reverse()
-    #
-    last = list.pop(0)
-    cmd.set_color("_000",[last[0]/255.0,last[1]/255.0,last[2]/255.0])
-    c = 1
-    for a in list:
-        for b in range(1,21):
-            b0 = b/20.0
-            b1 = 1.0-b0
-            cname = "_%03d"%c
-            r = last[0]*b1+a[0]*b0
-            g = last[1]*b1+a[1]*b0
-            b = last[2]*b1+a[2]*b0
-            cmd.set_color(cname,[r/255.0,g/255.0,b/255.0])
-            c = c + 1
-        last = a
+    list = ['0x%02x%02x%02x' % rgb for rgb in list]
+    _self.spectrum('count', ' '.join(list), selection)
 
-    cas = cmd.index("((byres ("+selection+")) and name CA and not het)")
-    l = len(cas)
-    if not len(cas):
-        return
-    c = 0
-    for a in cas:
-        col = int((200*c)/l)
-        cmd.color("_%03d"%col,"((%s) and (byres %s`%d))"%(selection,a[0],a[1]))
-        c = c + 1
 
-    cmd.feedback("pop")
-    
 def ss(selection="(name CA and alt '',A)",state=1,_self=cmd):
     '''
     Legacy secondary structure assignment routine. Don't use.
 
     Use instead: dss
     '''
-    pymol=_self._pymol
-    cmd=_self # NOT THREAD SAFE
+    print(' util.ss: Deprecated, use cmd.dss() instead')
+    _self.dss(selection, state)
 
-    print(' util.ss: WARNING: This is not a "correct" secondary structure')
-    print(' util.ss: assignment algorithm!  Please use only as a last resort.')
-    
-    cmd.feedback("push")
-    cmd.feedback("disable","executive","actions")
-    
-    ss_pref = "_sss"
-    sss1 = ss_pref+"1"
-    cnt = cmd.select(sss1,"((byres ("+selection+")) and name CA and not het)")
-    print(" util.ss: initiating secondary structure assignment on %d residues."%cnt)
-    cas = cmd.index(sss1)
-    if not len(cas):
-        return
-    # set cartoon mode to auto over the selection
-    
-    cmd.cartoon("auto",sss1)
-
-    print(" util.ss: extracting sequence and relationships...")
-
-    # get CA list
-    
-    res_list = []
-    pymol._ss = pymol.Scratch_Storage()
-    pymol._ss.res_list = res_list
-    cmd.iterate(sss1,'_ss.res_list.append((model,index))')
-
-    # generate atom-to-residue conversion dictionaries
-
-    ca_dict = {}
-    n_dict = {}
-    o_dict = {}
-    scr_dict = {} # scr = segment,chain,resi 
-    pymol._ss.n_dict = n_dict
-    pymol._ss.o_dict = o_dict
-    pymol._ss.scr_dict = scr_dict
-    pymol._ss.ca_dict = ca_dict
-    cmd.iterate(sss1,
-                    '_ss.scr_dict[(model,index)]=(segi,chain,resi)') # CA's
-    cmd.iterate("((byres "+sss1+") and n;N)"
-                    ,'_ss.scr_dict[(model,index)]=(segi,chain,resi)') # N's
-    cmd.iterate("((byres "+sss1+") and n;O)",
-                    '_ss.scr_dict[(model,index)]=(segi,chain,resi)') # O's
-    cmd.iterate(sss1,
-                    '_ss.ca_dict[(segi,chain,resi)] = (model,index)')
-    cmd.iterate("((byres "+sss1+") and n;N)",
-                    '_ss.n_dict[(segi,chain,resi)] = (model,index)')
-    cmd.iterate("((byres "+sss1+") and n;O)",
-                    '_ss.o_dict[(segi,chain,resi)] = (model,index)')
-
-    scr_dict[None]=None
-    o_dict[None]=None
-    n_dict[None]=None
-    ca_dict[None]=None
-    
-    # create special version of cas with gaps
-
-    gap = [None,None,None,None]  
-    # gap large enough to distinguish i+4 interations from gaps
-    last = None
-    for a in res_list:
-        if last!=None:
-            if(cmd.count_atoms(
-                "((neighbor(neighbor(neighbor (%s`%d)))) and (%s`%d))"%
-                (last[0],last[1],a[0],a[1]),quiet=1)==0):
-                gap.extend([None,None,None,None])
-        gap.append(a)
-        last = a
-    gap.extend([None,None,None,None])
-
-    print(" util.ss: analyzing phi/psi angles (slow)...")
-
-    # generate reverse-lookup for gap indices
-
-    ss = {}
-
-    c = 0
-    gap_idx = {}
-    for a in gap:
-        gap_idx[a] = c
-        c = c + 1
-
-    # secondary structure database...
-    
-    ss = {}
-    ss[None]=None
-    
-    # make decisions based on phi/psi
-
-    for a in cas:
-        ss[a] = 'L' # default
-    phipsi = cmd.get_phipsi(sss1,state)
-    for a in phipsi.keys():
-        (phi,psi) = phipsi[a]
-#      print scr_dict[a],(phi,psi)
-        if (phi!=None) and (psi!=None):
-            if ((phi<-45) and (phi>-160) and
-                 (psi<-170) or (psi>10)): # beta?
-                ss[a] = 's'
-            elif ((phi<-45) and (phi>-160) and
-                    (psi>-80) and (psi<-25)): # helix?
-                ss[a] = 'H'
-                
-    print(" util.ss: finding hydrogen bonds...")
-    
-    # find all pairwise hydrogen bonds and make note of them in dict
-
-    hb = cmd.find_pairs("((byres "+sss1+") and n;N)",
-                              "((byres "+sss1+") and n;O)",mode=1,
-                              cutoff=3.7,angle=55,
-                              state1=state,state2=state)
-    
-    hb_dict = {}  # [((N-atom) (O-atom))] = 1
-    n_hb_dict = {} # [(N-atom)] = [(O-atom),...]
-    o_hb_dict = {} # [(O-atom)] = [(N-atom),...]
-    for a in hb:
-#      cmd.dist("(%s`%d)"%a[0],"(%s`%d)"%a[1])
-        hb_dict[a] = 1
-        n = a[0]
-        o = a[1]
-        if n not in n_hb_dict: n_hb_dict[n]=[]
-        if o not in o_hb_dict: o_hb_dict[o]=[]
-        n_hb_dict[n].append(o)
-        o_hb_dict[o].append(n)
-
-    # check to insure that all helical residues have at least an i +/- 4
-    # hydrogen bond
-
-    for c in range(4,len(gap)-4):
-        a = gap[c]
-        if ss[a]=='H':
-            aN = n_dict[scr_dict[a]]
-            aO = o_dict[scr_dict[a]]
-            am4O = o_dict[scr_dict[gap[c-4]]]
-            ap4N = n_dict[scr_dict[gap[c+4]]]
-            if (aN,am4O) not in hb_dict:
-                if (ap4N,aO) not in hb_dict:
-                    ss[a]='L'
-
-    print(" util.ss: verifying beta sheets...")
-    
-    # check to insure that all beta residues have proper interactions
-
-    rep_dict = {}
-    repeat = 1
-    while repeat:
-        repeat = 0
-        c = 4
-        cc = len(gap)-4
-        while c<cc:
-            a1 = gap[c]
-            if (ss[a1] in ['s','S']) and a1 not in rep_dict:
-                rep_dict[a1] = 1
-                valid = 0
-                scr_a1 = scr_dict[a1]
-                # look for antiparallel 2:2 H-bonds (NH-O=C + C=O-HN) 
-                n_a1_atom = n_dict[scr_a1]
-                o_a1_atom = o_dict[scr_a1]
-                if (n_a1_atom in n_hb_dict and 
-                     o_a1_atom in o_hb_dict):
-                    for n_hb_atom in n_hb_dict[n_a1_atom]:
-                        for o_hb_atom in o_hb_dict[o_a1_atom]:
-                            n_hb_scr = scr_dict[n_hb_atom]
-                            o_hb_scr = scr_dict[o_hb_atom]
-                            if o_hb_scr == n_hb_scr:
-                                b1 = ca_dict[o_hb_scr]
-                                if abs(c-gap_idx[b1])>2:
-                                    ss[b1] = 'S' 
-                                    ss[a1] = 'S' 
-                                    valid = 1
-                # look for antiparallel offset HB (i,i+2,j,j-2)
-                a3 = gap[c+2]
-                if (a3!=None):
-                    scr_a3 = scr_dict[a3]
-                    o_a1_atom = o_dict[scr_a1]
-                    n_a3_atom = n_dict[scr_a3]
-                    if (n_a3_atom in n_hb_dict and
-                         o_a1_atom in o_hb_dict):               
-                        for n_hb_atom in n_hb_dict[n_a3_atom]:
-                            for o_hb_atom in o_hb_dict[o_a1_atom]:
-                                n_hb_scr = scr_dict[n_hb_atom]
-                                o_hb_scr = scr_dict[o_hb_atom]
-                                b1 = ca_dict[o_hb_scr]
-                                if b1!=None:
-                                    b1_i = gap_idx[b1]
-                                    if abs(c-b1_i)>2: # no turns!
-                                        b3 = gap[b1_i-2]
-                                        if b3!=None:
-                                            b3_scr = scr_dict[b3]
-                                            if b3_scr == n_hb_scr:
-                                                a2 = gap[c+1]
-                                                b2 = gap[gap_idx[b1]-1]
-                                                ss[b1] = 'S'
-                                                ss[b3] = 'S'
-                                                ss[a1] = 'S'
-                                                ss[a3] = 'S'
-                                                if ss[a2]=='L': ss[a2] = 's'
-                                                if ss[b2]=='L': ss[b2] = 's'
-                                                valid = 1
-                # look for antiparallel offset HB (i,i-2,j,j+2)
-                a3 = gap[c-2]
-                if (a3!=None):
-                    scr_a3 = scr_dict[a3]
-                    n_a1_atom = n_dict[scr_a1]
-                    o_a3_atom = o_dict[scr_a3]
-                    if (n_a1_atom in n_hb_dict and
-                         o_a3_atom in o_hb_dict):               
-                        for n_hb_atom in n_hb_dict[n_a1_atom]:
-                            for o_hb_atom in o_hb_dict[o_a3_atom]:
-                                n_hb_scr = scr_dict[n_hb_atom]
-                                o_hb_scr = scr_dict[o_hb_atom]
-                                b1 = ca_dict[o_hb_scr]
-                                if b1!=None:
-                                    b1_i = gap_idx[b1]
-                                    if abs(c-b1_i)>2: # no turns!
-                                        b3 = gap[b1_i-2]
-                                        if b3!=None:
-                                            b3_scr = scr_dict[b3]
-                                            if b3_scr == n_hb_scr:
-                                                a2 = gap[c-1]
-                                                b2 = gap[gap_idx[b1]-1]
-                                                ss[b1] = 'S'
-                                                ss[b3] = 'S'
-                                                ss[a1] = 'S'
-                                                ss[a3] = 'S'
-                                                if ss[a2]=='L': ss[a2] = 's'
-                                                if ss[b2]=='L': ss[b2] = 's'
-                                                valid = 1
-                # look for parallel 1:3 HB (i,j-1,j+1)
-                n_a1_atom = n_dict[scr_a1]
-                o_a1_atom = o_dict[scr_a1]
-                if (n_a1_atom in n_hb_dict and
-                     o_a1_atom in o_hb_dict):
-                    for n_hb_atom in n_hb_dict[n_a1_atom]:
-                        for o_hb_atom in o_hb_dict[o_a1_atom]:
-                            n_hb_scr = scr_dict[n_hb_atom]
-                            o_hb_scr = scr_dict[o_hb_atom]
-                            b0 = ca_dict[n_hb_scr]
-                            if b0!=None:
-                                b2 = gap[gap_idx[b0]+2]
-                                if b2!=None:
-                                    b2_scr = scr_dict[b2]
-                                    if b2_scr == o_hb_scr:
-                                        b1 = gap[gap_idx[b0]+1]
-                                        ss[a1] = 'S' 
-                                        ss[b0] = 'S'
-                                        if ss[b1]=='L': ss[b1]='s'
-                                        ss[b2] = 'S'
-                                        valid = 1
-                                        repeat = 1
-                if not valid:
-                    ss[a1] = 'L'
-            c = c + 1
-
-    # automatically fill 1 residue gaps in helices and well-defined sheets
-    c = 4
-    cc = len(gap)-6
-    while c<cc:
-        a1 = gap[c]
-        a3 = gap[c+2]
-        ss_a1 = ss[a1]
-        ss_a3 = ss[a3]
-        if (ss_a1==ss_a3) and (ss_a1 in ['S','H']):
-            a2 = gap[c+1]
-            ss[a2] = ss_a1
-        c = c + 1
-
-    # remove singleton sheet residues
-    c = 4
-    cc = len(gap)-4
-    while c<cc:
-        a0 = gap[c-1]
-        a1 = gap[c]
-        a2 = gap[c+1]
-        if ss[a1] in ['s','S']:
-            if ((not ss[a0] in ['s','S']) and
-                 (not ss[a2] in ['s','S'])):
-                 ss[a1] = 'L'
-        c = c + 1
-
-    # remove sheet residues which aren't next to another sheet 
-    c = 4
-    cc = len(gap)-4
-    while c<cc:
-        a1 = gap[c]
-        if ss[a1]=='S':
-            a1 = gap[c]
-            scr_a1 = scr_dict[a1]
-            # look for hydrogen bonds to another sheet
-            n_a1_atom = n_dict[scr_a1]
-            o_a1_atom = o_dict[scr_a1]
-            certain = 0
-            if n_a1_atom in n_hb_dict:
-                for n_hb_atom in n_hb_dict[n_a1_atom]:
-                    n_hb_ca_atom=ca_dict[scr_dict[n_hb_atom]]
-                    if ss[n_hb_ca_atom]=='S':
-                        certain = 1
-                        break
-            if o_a1_atom in o_hb_dict:
-                for o_hb_atom in o_hb_dict[o_a1_atom]:
-                    o_hb_ca_atom=ca_dict[scr_dict[o_hb_atom]]
-                    if ss[o_hb_ca_atom]=='S':
-                        certain = 1
-                        break
-            if not certain:
-                ss[a1] = 's'
-        c = c + 1
-
-    # remove questionable sheet residues
-    c = 4
-    cc = len(gap)-4
-    while c<cc:
-        a0 = gap[c-1]
-        a1 = gap[c]
-        a2 = gap[c+1]
-        if ss[a1]=='s':
-            if (not ((ss[a0]=='S') and (ss[a2]=='S'))):
-                ss[a1] = 'L'
-        c = c + 1
-
-    # extend helices if hydrogen bonding requirements are met
-    rep_dict = {}
-    repeat = 1
-    while repeat:
-        repeat = 0
-        c = 4
-        cc = len(gap)-4
-        while c<cc:
-            a = gap[c]
-            if a not in rep_dict:
-                if ss[gap[c+1]]=='H':
-                    rep_dict[a] = 1
-                    if ss[a]!='H': # N-terminal end
-                        aO = o_dict[scr_dict[a]]
-                        ap4N = n_dict[scr_dict[gap[c+4]]]
-                        ap3N = n_dict[scr_dict[gap[c+3]]]
-                        if (ap4N,aO) in hb_dict or (ap3N,aO) in hb_dict:
-                            ss[a]='H'
-                            repeat = 1
-                            c = c - 5
-                            if c<4: c=4
-                if ss[gap[c-1]]=='H':
-                    a = gap[c]
-                    if ss[a]!='H': # C-terminal end
-                        rep_dict[a] = 1
-                        aN = n_dict[scr_dict[a]]
-                        am4O = o_dict[scr_dict[gap[c-4]]]
-                        am3O = o_dict[scr_dict[gap[c-3]]]
-                        if (aN,am4O) in hb_dict or (aN,am3O) in hb_dict:
-                            ss[a]='H'
-                            repeat = 1
-                            c = c - 5
-                            if c<4: c=4
-            c = c + 1
-
-    # remove doubleton helices
-
-    c = 4
-    cc = len(gap)-5
-    while c<cc:
-        a0 = gap[c-1]
-        a1 = gap[c]
-        a2 = gap[c+1]
-        a3 = gap[c+2]
-        ss_a0 = ss[gap[c-1]]
-        ss_a1 = ss[gap[c]]
-        ss_a2 = ss[gap[c+1]]
-        ss_a3 = ss[gap[c+2]]
-        if ss_a1=='H':
-            if (ss_a2==ss_a1) and (ss_a0!=ss_a2) and (ss_a2!=ss_a3):
-                ss[a1] = 'L'
-                ss[a2] = 'L'
-        c = c + 1
-
-    # remove totally unreasonable helix and sheet residues
-
-    c = 4
-    cc = len(gap)-5
-    while c<cc:
-        a1 = gap[c]
-        ss_a1 = ss[gap[c]]
-        if ss_a1=='H':
-            if a1 in phipsi:
-                (phi,psi) = phipsi[a1]
-                if (phi>0) and (phi<150):
-                    ss[a1] = 'L'
-                elif((psi<-120) or (psi>140)):
-                    ss[a1] = 'L'
-        elif ss_a1 in ['S','s']:
-            if a1 in phipsi:
-                (phi,psi) = phipsi[a1]
-                if (phi>45) and (phi<160):
-                    ss[a1] = 'L'
-#            if (psi<-30) and (psi>-150):
-                if (psi<-65) and (psi>-150):
-                    ss[a1] = 'L'
-            
-        c = c + 1
-
-
-    for x in range(1,3):
-        # remove singleton sheet residues
-        c = 4
-        cc = len(gap)-4
-        while c<cc:
-            a0 = gap[c-1]
-            a1 = gap[c]
-            a2 = gap[c+1]
-            if ss[a1] in ['s','S']:
-                if ((not ss[a0] in ['s','S']) and
-                     (not ss[a2] in ['s','S'])):
-                     ss[a1] = 'L'
-            c = c + 1
-
-        # remove sheet residues which aren't next to another sheet 
-        c = 4
-        cc = len(gap)-4
-        while c<cc:
-            a1 = gap[c]
-            if ss[a1]=='S':
-                a1 = gap[c]
-                scr_a1 = scr_dict[a1]
-                # look for hydrogen bonds to another sheet
-                n_a1_atom = n_dict[scr_a1]
-                o_a1_atom = o_dict[scr_a1]
-                certain = 0
-                if n_a1_atom in n_hb_dict:
-                    for n_hb_atom in n_hb_dict[n_a1_atom]:
-                        n_hb_ca_atom=ca_dict[scr_dict[n_hb_atom]]
-                        if ss[n_hb_ca_atom]=='S':
-                            certain = 1
-                            break
-                if o_a1_atom in o_hb_dict:
-                    for o_hb_atom in o_hb_dict[o_a1_atom]:
-                        o_hb_ca_atom=ca_dict[scr_dict[o_hb_atom]]
-                        if ss[o_hb_ca_atom]=='S':
-                            certain = 1
-                            break
-                if not certain:
-                    ss[a1] = 's'
-            c = c + 1
-
-        # remove questionable sheet residues
-        c = 4
-        cc = len(gap)-4
-        while c<cc:
-            a0 = gap[c-1]
-            a1 = gap[c]
-            a2 = gap[c+1]
-            if ss[a1]=='s':
-                if (not ((ss[a0]=='S') and (ss[a2]=='S'))):
-                    ss[a1] = 'L'
-            c = c + 1
-
-#      lst = ss.keys()
-#      lst.sort()
-#      for a in lst: print scr_dict[a],ss[a]
-        
-    # assign protein
-    for a in cas:
-        if ss[a]=='s':
-            ss[a]='S'
-        
-    cmd.alter(sss1,"ss ='L'")
-    for a in cas:
-        if ss[a]!='L':
-            cmd.alter("(%s`%d)"%a,"ss='%s'"%ss[a])
-
-    cmd.feedback("pop")
-
-    del pymol._ss # IMPORTANT
-    cmd.delete(sss1)
-    cmd.rebuild(selection,'cartoon')
-    #
-#   print conn_hash.keys()
-    print(" util.ss: assignment complete.")
 
 def colors(scheme="",_self=cmd):
     cmd=_self
@@ -1693,7 +1178,7 @@ SEE ALSO
     return resarea
 
 
-def ligand_zoom(_self=cmd):
+def ligand_zoom(step=1, _self=cmd):
     '''
 DESCRIPTION
 
@@ -1715,7 +1200,7 @@ DESCRIPTION
     except (ValueError, NameError):
         i = -1
 
-    i = (i + 1) % len(ligands)
+    i = (i + int(step)) % len(ligands)
     _current_ligand = ligands[i]
 
     # use "do" for feedback
